"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.delay = void 0;
const react_1 = require("react");
const capacitor_voice_recorder_1 = require("capacitor-voice-recorder");
const upload_records_1 = __importDefault(require("./upload-records"));
const delay = (time) => new Promise(res => setTimeout(() => res(), time));
exports.delay = delay;
function useRecordingCycle({ deep, recording, containerLinkId, duration }) {
    const [records, setRecords] = (0, react_1.useState)([]);
    (0, react_1.useEffect)(() => {
        const useRecords = () => __awaiter(this, void 0, void 0, function* () {
            yield (0, upload_records_1.default)({ deep, containerLinkId, records });
            setRecords([]);
        });
        if (records.length > 0)
            useRecords();
    }, [records]);
    (0, react_1.useEffect)(() => {
        let loop = true;
        const startRecordingCycle = () => __awaiter(this, void 0, void 0, function* () {
            for (; recording && loop;) {
                capacitor_voice_recorder_1.VoiceRecorder.startRecording();
                const startTime = new Date().toLocaleDateString();
                yield (0, exports.delay)(duration);
                const { value: sound } = yield capacitor_voice_recorder_1.VoiceRecorder.stopRecording();
                const endTime = new Date().toLocaleDateString();
                setRecords([...records, { sound, startTime, endTime }]);
            }
        });
        if (recording)
            startRecordingCycle();
        return function stopCycle() { loop = false; };
    }, [recording]);
    return records;
}
exports.default = useRecordingCycle;
